# <PROYECT_NAME>
# py.business_intelligence
Elastic demand: The first tools that this library presents are the calculations of elastic demand, useful for understanding the changes in demand when the price increases or decreases.
